# Clustering utilities
Clustering can be achieved using one the four implemented clustering algorithms:

```{eval-rst}

.. currentmodule:: cytonormpy

.. autosummary::
    :toctree: ../generated/
    :nosignatures:
    
    FlowSOM
    KMeans
    MeanShift
    AffinityPropagation
```

